==> openshift-model-console-5.12.0-sources.jar: io/fabric8/openshift/api/model/console/v1/LinkBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class LinkBuilder extends io.fabric8.openshift.api.model.console.v1.LinkFluentImpl<io.fabric8.openshift.api.model.console.v1.LinkBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.console.v1.Link,io.fabric8.openshift.api.model.console.v1.LinkBuilder>{
  public LinkBuilder() {
    this(false);
  }
  public LinkBuilder(java.lang.Boolean validationEnabled) {
    this(new Link(), validationEnabled);
  }
  public LinkBuilder(io.fabric8.openshift.api.model.console.v1.LinkFluent<?> fluent) {
    this(fluent, false);
  }
  public LinkBuilder(io.fabric8.openshift.api.model.console.v1.LinkFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Link(), validationEnabled);
  }
  public LinkBuilder(io.fabric8.openshift.api.model.console.v1.LinkFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.Link instance) {
    this(fluent, instance, false);
  }
  public LinkBuilder(io.fabric8.openshift.api.model.console.v1.LinkFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.Link instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withHref(instance.getHref()); 
    fluent.withText(instance.getText()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public LinkBuilder(io.fabric8.openshift.api.model.console.v1.Link instance) {
    this(instance,false);
  }
  public LinkBuilder(io.fabric8.openshift.api.model.console.v1.Link instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withHref(instance.getHref()); 
    this.withText(instance.getText()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.console.v1.LinkFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.console.v1.Link build() {
    Link buildable = new Link(fluent.getHref(),fluent.getText());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LinkBuilder that = (LinkBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-console-6.2.0-sources.jar: io/fabric8/openshift/api/model/console/v1/LinkBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LinkBuilder extends LinkFluentImpl<LinkBuilder> implements VisitableBuilder<Link,LinkBuilder>{
  public LinkBuilder() {
    this(false);
  }
  public LinkBuilder(Boolean validationEnabled) {
    this(new Link(), validationEnabled);
  }
  public LinkBuilder(LinkFluent<?> fluent) {
    this(fluent, false);
  }
  public LinkBuilder(LinkFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Link(), validationEnabled);
  }
  public LinkBuilder(LinkFluent<?> fluent,Link instance) {
    this(fluent, instance, false);
  }
  public LinkBuilder(LinkFluent<?> fluent,Link instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withHref(instance.getHref()); 
    fluent.withText(instance.getText()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public LinkBuilder(Link instance) {
    this(instance,false);
  }
  public LinkBuilder(Link instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withHref(instance.getHref()); 
    this.withText(instance.getText()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  LinkFluent<?> fluent;
  Boolean validationEnabled;
  public Link build() {
    Link buildable = new Link(fluent.getHref(),fluent.getText());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
